@@ -8,8 +8,8 @@ from __future__ import annotations
 
 import asyncio as aio
 import datetime as dt
-from typing import Any, Callable, Optional, cast
 from logging import Logger
+from typing import Any, Callable, Optional, cast
 
 import typeguard as tg
 
@@ -135,9 +135,7 @@ class Scheduler(BaseScheduler):
         **kwargs,
     ) -> Job:
         """Encapsulate the `Job` and add the `Scheduler`'s timezone."""
-        job: Job = create_job_instance(
-            Job, tzinfo=self.__tzinfo, **kwargs
-        )
+        job: Job = create_job_instance(Job, tzinfo=self.__tzinfo, **kwargs)
 
         task = self.__loop.create_task(self.__supervise_job(job))
         self.__jobs[job] = task
@@ -151,7 +149,9 @@ class Scheduler(BaseScheduler):
                 sleep_seconds: float = job.timedelta(reference_dt).total_seconds()
                 await aio.sleep(sleep_seconds)
 
-                await job._exec(logger=self._BaseScheduler__logger)  # pylint: disable=protected-access
+                await job._exec(
+                    logger=self._BaseScheduler__logger
+                )  # pylint: disable=protected-access
 
                 reference_dt = dt.datetime.now(tz=self.__tzinfo)
                 job._calc_next_exec(reference_dt)  # pylint: disable=protected-access
